<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis06200DimeScFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis06200DimeScService
{
    protected $environment;
    protected $dimeScFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis06200DimeScFactory $dimeScFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->dimeScFactory        = $dimeScFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação DIME-SC
     */
    private function createFileDimeSc($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $dimeScData = $this->dimeScFactory->getDimeScData($params);
        
        if(isset($row['NRAGENDAMENTO']) && empty($dimeScData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $dimeScData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação DIME-SC
     */
    public function exportarDimeSc($row) {
        // Valida os parâmetros associados.
        $this->validateDimeSc($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);
        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA'     => $row['CDEMPRESA'],
            'CDIMPOSTO'     => '00',
            'CDINSCESTA'    => $row['CDINSCESTA'],
            'DTINICIAL'     => $row['DTINICIAL'],
            'DTFINAL'       => $row['DTFINAL'],
            'DECLARACAO'    => $row['STTIPODECLARACAO'],
            'REGIME'        => $row['STTIPOREGIME'],
            'CONSOLIDADA'   => $row['STCONSOLIDADA'],
            'CENTRALIZADA'  => $row['STCENTRALIZADA'],
            'MOVIMENTO'     => $row['STMOVIMENTO'],
            'TRIBUTARIO'    => $row['STTRIBUTARIO'],
            'ESCCONTABIL'   => $row['STESCCONTABIL'],
            'CLASVENC'      => $row["STCLASSE"],
            'NMTRAB'        => $row['STNUMTRAB'],
            'INCFISC'       => $row['STINCFISCAL'],
            'INVENTARIO'    => $row['STGERINVENTARIO'],
            'NRSEQARQMAG'   => $row['NRSEQARQMAG'],
            'GERACONTAB'    => $row['GERAREGISTRO'],
            'ATIVO'         => $row['CDATIVO'],
            'PASSIVO'       => $row['CDPASSIVO'],
            'DRE'           => $row['CDDRE'],
            'DESPESAS'      => $row['CDDESPESAS'],
            'DTREFCTB'      => $row['DTREFCTB'],
            'TPATIVIDADE'   => $row['STTPATIVIDADE'],
        ];
        
        // Chama a procedure de exportação
        $this->dimeScFactory->callDimeScProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileDimeSc($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->dimeScFactory->deleteDimeScData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->dimeScFactory->deleteDimeScData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o DIME-SC
     */
    private function validateDimeSc($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
        
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Gera Registros de Balanço Patrimonial' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Gera Registros de Balanço Patrimonial deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Gera Registros de Balanço Patrimonial deve ser informado');
            }
            // Verifica se o campo 'Classe de Vencimento' possui algum vlr informado
            if(empty($row['STCLASSE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Classe de Vencimento deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Classe de Vencimento deve ser informado');
            }
            // Verifica se o campo 'Número de Trabalhadores' possui algum vlr informado
            if(empty($row['STNUMTRAB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Número de Trabalhadores deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Número de Trabalhadores deve ser informado');
            }
            // Verifica se o campo 'Tipo de Declaração' possui algum vlr informado
            if(empty($row['STTIPODECLARACAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Tipo de Declaração deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Tipo de Declaração deve ser informado');
            }
            // Verifica se o campo 'Regime de Apuração' possui algum vlr informado
            if(empty($row['STTIPOREGIME'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Regime de Apuração deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Regime de Apuração deve ser informado');
            }
            // Verifica se o campo 'Apuração Consolidada' possui algum vlr informado
            if(empty($row['STCONSOLIDADA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Apuração Consolidada deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Apuração Consolidada deve ser informado');
            }
            // Verifica se o campo 'Apuração Centralizada' possui algum vlr informado
            if(empty($row['STCENTRALIZADA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Apuração Centralizada deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Apuração Centralizada deve ser informado');
            }
            // Verifica se o campo 'Movimento' possui algum vlr informado
            if(empty($row['STMOVIMENTO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Movimento deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Movimento deve ser informado');
            }
            // Verifica se o campo 'Substituto Tributário' possui algum vlr informado
            if(empty($row['STTRIBUTARIO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Substituto Tributário deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Substituto Tributário deve ser informado');
            }
            // Verifica se o campo 'Escrita Contábil' possui algum vlr informado
            if(empty($row['STESCCONTABIL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Escrita Contábil deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Escrita Contábil deve ser informado');
            }
            // Verifica se o campo 'Incentivo Fiscal' possui algum vlr informado
            if(empty($row['STINCFISCAL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incentivo Fiscal deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Incentivo Fiscal deve ser informado');
            }
            // Verifica se o campo 'Gerar Inventário' possui algum vlr informado
            if(empty($row['STGERINVENTARIO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Gerar Inventário deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Gerar Inventário deve ser informado');
            }
            // Verifica se o campo 'Tipo de Atividade' possui algum vlr informado
            if(empty($row['STTPATIVIDADE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Tipo de Atividade deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Tipo de Atividade deve ser informado');
            }
            
            if($row["GERAREGISTRO"] == "S"){
                // Verifica se o campo 'Ativo' possui algum vlr informado
                if(empty($row['CDATIVO'])){
                    $this->mensagemError = $this->mensagemError.'<br />'.'Ativo deve ser informado.';
                    $this->geraArquivo = false;
                    //throw new \Exception('Ativo deve ser informado');
                }
                // Verifica se o campo 'Passivo' possui algum vlr informado
                if(empty($row['CDPASSIVO'])){
                    $this->mensagemError = $this->mensagemError.'<br />'.'Passivo deve ser informado.';
                    $this->geraArquivo = false;
                    //throw new \Exception('Passivo deve ser informado');
                }
                // Verifica se o campo 'Demostração de Resultado' possui algum vlr informado
                if(empty($row['CDDRE'])){
                    $this->mensagemError = $this->mensagemError.'<br />'.'Demostração de Resultado deve ser informada.';
                    $this->geraArquivo = false;
                    //throw new \Exception('Demostração de Resultado deve ser informado');
                }
                // Verifica se o campo 'Demonstração das Despesas' possui algum vlr informado
                if(empty($row['CDDESPESAS'])){
                    $this->mensagemError = $this->mensagemError.'<br />'.'Demonstração das Despesas deve ser informada.';
                    $this->geraArquivo = false;
                    //throw new \Exception('Demonstração das Despesas deve ser informado');
                }
                // Verifica se o campo 'Data de Referência Contábil' possui algum vlr informado
                if(empty($row['DTREFCTB'])){
                    $this->mensagemError = $this->mensagemError.'<br />'.'Data de Referência Contábil deve ser informada.';
                    $this->geraArquivo = false;
                    //throw new \Exception('Data de Referência Contábil deve ser informado');
                }
                
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL']   = $datas['DTINICIAL'];
            $row['DTFINAL']     = $datas['DTFINAL'];

            //$row['NRORG'] = $nrorg;
    
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Inscrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Gera Registros de Balanço Patrimonial' possui algum vlr informado
            if(empty($row['GERAREGISTRO'])){
                throw new \Exception('Gera Registros de Balanço Patrimonial deve ser informado');
            }
            if($row["GERAREGISTRO"] == "S"){
                // Verifica se o campo 'Ativo' possui algum vlr informado
                if(empty($row['CDATIVO'])){
                    throw new \Exception('Ativo deve ser informado');
                }
                // Verifica se o campo 'Passivo' possui algum vlr informado
                if(empty($row['CDPASSIVO'])){
                    throw new \Exception('Passivo deve ser informado');
                }
                // Verifica se o campo 'Demostração de Resultado' possui algum vlr informado
                if(empty($row['CDDRE'])){
                    throw new \Exception('Demostração de Resultado deve ser informado');
                }
                // Verifica se o campo 'Demonstração das Despesas' possui algum vlr informado
                if(empty($row['CDDESPESAS'])){
                    throw new \Exception('Demonstração das Despesas deve ser informado');
                }
                // Verifica se o campo 'Data de Referência Contábil' possui algum vlr informado
                if(empty($row['DTREFCTB'])){
                    throw new \Exception('Data de Referência Contábil deve ser informado');
                }
            }
            // Verifica se o campo 'Classe de Vencimento' possui algum vlr informado
            if(empty($row['STCLASSE'])){
                throw new \Exception('Classe de Vencimento deve ser informado');
            }
            // Verifica se o campo 'Número de Trabalhadores' possui algum vlr informado
            if(empty($row['STNUMTRAB'])){
                throw new \Exception('Número de Trabalhadores deve ser informado');
            }
            // Verifica se o campo 'Tipo de Declaração' possui algum vlr informado
            if(empty($row['STTIPODECLARACAO'])){
                throw new \Exception('Tipo de Declaração deve ser informado');
            }
            // Verifica se o campo 'Regime de Apuração' possui algum vlr informado
            if(empty($row['STTIPOREGIME'])){
                throw new \Exception('Regime de Apuração deve ser informado');
            }
            // Verifica se o campo 'Apuração Consolidada' possui algum vlr informado
            if(empty($row['STCONSOLIDADA'])){
                throw new \Exception('Apuração Consolidada deve ser informado');
            }
            // Verifica se o campo 'Apuração Centralizada' possui algum vlr informado
            if(empty($row['STCENTRALIZADA'])){
                throw new \Exception('Apuração Centralizada deve ser informado');
            }
            // Verifica se o campo 'Movimento' possui algum vlr informado
            if(empty($row['STMOVIMENTO'])){
                throw new \Exception('Movimento deve ser informado');
            }
            // Verifica se o campo 'Substituto Tributário' possui algum vlr informado
            if(empty($row['STTRIBUTARIO'])){
                throw new \Exception('Substituto Tributário deve ser informado');
            }
            // Verifica se o campo 'Escrita Contábil' possui algum vlr informado
            if(empty($row['STESCCONTABIL'])){
                throw new \Exception('Escrita Contábil deve ser informado');
            }
            // Verifica se o campo 'Incentivo Fiscal' possui algum vlr informado
            if(empty($row['STINCFISCAL'])){
                throw new \Exception('Incentivo Fiscal deve ser informado');
            }
            // Verifica se o campo 'Gerar Inventário' possui algum vlr informado
            if(empty($row['STGERINVENTARIO'])){
                throw new \Exception('Gerar Inventário deve ser informado');
            }
            // Verifica se o campo 'Tipo de Atividade' possui algum vlr informado
            if(empty($row['STTPATIVIDADE'])){
                throw new \Exception('Tipo de Atividade deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL']   = $datas['DTINICIAL'];
            $row['DTFINAL']     = $datas['DTFINAL'];
            $row['NRORG']       = $nrorg;
            
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->dimeScFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS06200';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->dimeScFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->dimeScFactory->insertAgendamento($row);
            } else {
                $this->dimeScFactory->updateAgendamento($row);
                
                 $arquivos = $this->dimeScFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dimeScFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->dimeScFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->dimeScFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->dimeScFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - DIME (Santa Catarina)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoDimeSc';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->dimeScFactory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->dimeScFactory->findParamDeclAcess($agendamento);
            
            $agendamento['STCLASSE']            = isset($findParamDeclAcess['STCLASSE']) ? $findParamDeclAcess['STCLASSE'] : null;
            $agendamento['STNUMTRAB']           = isset($findParamDeclAcess['STNUMTRAB']) ? $findParamDeclAcess['STNUMTRAB'] : null;
            $agendamento['STTIPODECLARACAO']    = isset($findParamDeclAcess['STTIPODECLARACAO']) ? $findParamDeclAcess['STTIPODECLARACAO'] : null;
            $agendamento['STTIPOREGIME']        = isset($findParamDeclAcess['STTIPOREGIME']) ? $findParamDeclAcess['STTIPOREGIME'] : null;
            $agendamento['STCONSOLIDADA']       = isset($findParamDeclAcess['STCONSOLIDADA']) ? $findParamDeclAcess['STCONSOLIDADA'] : null;
            $agendamento['STCENTRALIZADA']      = isset($findParamDeclAcess['STCENTRALIZADA']) ? $findParamDeclAcess['STCENTRALIZADA'] : null;
            $agendamento['STMOVIMENTO']         = isset($findParamDeclAcess['STMOVIMENTO']) ? $findParamDeclAcess['STMOVIMENTO'] : null;
            $agendamento['STTRIBUTARIO']        = isset($findParamDeclAcess['STTRIBUTARIO']) ? $findParamDeclAcess['STTRIBUTARIO'] : null;
            $agendamento['STESCCONTABIL']       = isset($findParamDeclAcess['STESCCONTABIL']) ? $findParamDeclAcess['STESCCONTABIL'] : null;
            $agendamento['STINCFISCAL']         = isset($findParamDeclAcess['STINCFISCAL']) ? $findParamDeclAcess['STINCFISCAL'] : null;
            $agendamento['STGERINVENTARIO']     = isset($findParamDeclAcess['STGERINVENTARIO']) ? $findParamDeclAcess['STGERINVENTARIO'] : null;
            $agendamento['STTPATIVIDADE']       = isset($findParamDeclAcess['STTPATIVIDADE']) ? $findParamDeclAcess['STTPATIVIDADE'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->dimeScFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->dimeScFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'DIME (Santa Catarina) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->dimeScFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de DIME (Santa Catarina) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de DIME (Santa Catarina):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } 
                        else if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } 
                        else if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                        
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                        
                        $fileName = $this->exportarDimeSc($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->dimeScFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->dimeScFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->dimeScFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->dimeScFactory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->dimeScFactory->getConfiguraSMTP($agendamento)[0];
                
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->dimeScFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dimeScFactory->deleteAgendamentoArquivo($arquivo);
                    $this->dimeScFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->dimeScFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
}